@@ -39,7 +39,12 @@ crsiv <- function(y,
                   iterate.tol=1.0e-05,
                   constant=0.5,
                   method=c("Landweber-Fridman","Tikhonov"),
-									opts=list("MAX_BB_EVAL"=500,"MIN_MESH_SIZE"="r1.0e-10","INITIAL_MESH_SIZE"="r1.0e-02","MIN_POLL_SIZE"="r1.0e-10","DISPLAY_DEGREE"=0),
+                  opts=list("MAX_BB_EVAL"=10000,
+                            "EPSILON"=.Machine$double.eps,
+                            "INITIAL_MESH_SIZE"="r1.0e-01",
+                            "MIN_MESH_SIZE"=paste("r",sqrt(.Machine$double.eps),sep=""),
+                            "MIN_POLL_SIZE"=paste("r",sqrt(.Machine$double.eps),sep=""),
+                            "DISPLAY_DEGREE"=0),
                   deriv=0,
                   ...) {
 
